@@ -8,7 +8,7 @@ package IO::Async::Loop::Select;
 use strict;
 use warnings;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 use constant API_VERSION => '0.33';
 
 use base qw( IO::Async::Loop );
@@ -23,11 +23,11 @@ C<IO::Async::Loop::Select> - use C<IO::Async> with C<select(2)>
 
 Normally an instance of this class would not be directly constructed by a
 program. It may however, be useful for runinng L<IO::Async> with an existing
-program already using a C<select()> call.
+program already using a C<select> call.
 
  use IO::Async::Loop::Select;
 
- my $loop = IO::Async::Loop::Select->new();
+ my $loop = IO::Async::Loop::Select->new;
 
  $loop->add( ... );
 
@@ -44,14 +44,14 @@ program already using a C<select()> call.
 
 =head1 DESCRIPTION
 
-This subclass of C<IO::Async::Loop> uses the C<select()> syscall to perform
+This subclass of C<IO::Async::Loop> uses the C<select(2)> syscall to perform
 read-ready and write-ready tests.
 
-To integrate with an existing C<select()>-based event loop, a pair of methods
-C<pre_select()> and C<post_select()> can be called immediately before and
-after a C<select()> call. The relevant bits in the read-ready, write-ready and
-exceptional-state bitvectors are set by the C<pre_select()> method, and tested
-by the C<post_select()> method to pick which event callbacks to invoke.
+To integrate with an existing C<select>-based event loop, a pair of methods
+C<pre_select> and C<post_select> can be called immediately before and
+after a C<select> call. The relevant bits in the read-ready, write-ready and
+exceptional-state bitvectors are set by the C<pre_select> method, and tested
+by the C<post_select> method to pick which event callbacks to invoke.
 
 =cut
 
@@ -59,7 +59,7 @@ by the C<post_select()> method to pick which event callbacks to invoke.
 
 =cut
 
-=head2 $loop = IO::Async::Loop::Select->new()
+=head2 $loop = IO::Async::Loop::Select->new
 
 This function returns a new instance of a C<IO::Async::Loop::Select> object.
 It takes no special arguments.
@@ -84,7 +84,7 @@ sub new
 
 =head2 $loop->pre_select( \$readvec, \$writevec, \$exceptvec, \$timeout )
 
-This method prepares the bitvectors for a C<select()> call, setting the bits
+This method prepares the bitvectors for a C<select> call, setting the bits
 that the Loop is interested in. It will also adjust the C<$timeout> value if
 appropriate, reducing it if the next event timeout the Loop requires is sooner
 than the current value.
@@ -123,7 +123,7 @@ sub pre_select
 
 =head2 $loop->post_select( $readvec, $writevec, $exceptvec )
 
-This method checks the returned bitvectors from a C<select()> call, and calls
+This method checks the returned bitvectors from a C<select> call, and calls
 any of the callbacks that are appropriate.
 
 =over 8
@@ -171,10 +171,10 @@ sub post_select
 
 =head2 $count = $loop->loop_once( $timeout )
 
-This method calls the C<pre_select()> method to prepare the bitvectors for a
-C<select()> syscall, performs it, then calls C<post_select()> to process the
+This method calls the C<pre_select> method to prepare the bitvectors for a
+C<select> syscall, performs it, then calls C<post_select> to process the
 result. It returns the total number of callbacks invoked by the
-C<post_select()> method, or C<undef> if the underlying C<select()> syscall
+C<post_select> method, or C<undef> if the underlying C<select(2)> syscall
 returned an error.
 
 =cut
@@ -224,7 +224,7 @@ sub unwatch_io
    vec( $self->{rvec}, $fileno, 1 ) = 0 if $params{on_read_ready};
    vec( $self->{wvec}, $fileno, 1 ) = 0 if $params{on_write_ready};
 
-   # vec() will grow a bit vector as needed, but never shrink it. We'll trim
+   # vec will grow a bit vector as needed, but never shrink it. We'll trim
    # trailing null bytes
    $_ =~s/\0+\z// for $self->{rvec}, $self->{wvec};
 }
